@@ -763,17 +763,14 @@ void KEditToolBarPrivate::okClicked()
         return;
     }
 
-    if (!m_widget->save()) {
-        // some error box here is needed
-    } else {
-        // Do not emit the "newToolBarConfig" signal again here if the "Apply"
-        // button was already pressed and no further changes were made.
-        if (m_buttonBox->button(QDialogButtonBox::Apply)->isEnabled()) {
-            emit q->newToolBarConfig();
-            emit q->newToolbarConfig(); // compat
-        }
-        q->accept();
+    // Do not rebuild GUI and emit the "newToolBarConfig" signal again here if the "Apply"
+    // button was already pressed and no further changes were made.
+    if (m_buttonBox->button(QDialogButtonBox::Apply)->isEnabled()) {
+        m_widget->save();
+        emit q->newToolBarConfig();
+        emit q->newToolbarConfig(); // compat
     }
+    q->accept();
 }
 
 void KEditToolBarPrivate::applyClicked()
@@ -909,7 +906,7 @@ void KEditToolBarWidgetPrivate::initFromFactory(KXMLGUIFactory *factory,
     }
 }
 
-bool KEditToolBarWidget::save()
+void KEditToolBarWidget::save()
 {
     //qDebug(240) << "KEditToolBarWidget::save";
     XmlDataList::Iterator it = d->m_xmlFiles.begin();
@@ -943,12 +940,10 @@ bool KEditToolBarWidget::save()
     }
 
     if (!d->m_factory) {
-        return true;
+        return;
     }
 
     rebuildKXMLGUIClients();
-
-    return true;
 }
 
 void KEditToolBarWidget::rebuildKXMLGUIClients()
@@ -1523,7 +1518,7 @@ void KEditToolBarWidgetPrivate::moveActive(ToolBarItem *item, ToolBarItem *befor
     if (!before) {
         m_currentToolBarElem.insertBefore(e, m_currentToolBarElem.firstChild());
     } else {
-        m_currentToolBarElem.insertAfter(e, findElementForToolBarItem((ToolBarItem *)before));
+        m_currentToolBarElem.insertAfter(e, findElementForToolBarItem(before));
     }
 
     // and set this container as a noMerge
